@@ -1,7 +1,7 @@
 use strict;
 use warnings;
-package Software::License::Apache_2_0;
-$Software::License::Apache_2_0::VERSION = '0.104003';
+package Software::License::Apache_2_0 0.104005;
+
 use parent 'Software::License';
 # ABSTRACT: The Apache License, Version 2.0
 
@@ -37,7 +37,7 @@ Software::License::Apache_2_0 - The Apache License, Version 2.0
 
 =head1 VERSION
 
-version 0.104003
+version 0.104005
 
 =head1 PERL VERSION
 
@@ -55,7 +55,7 @@ lower the minimum required perl.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@semiotic.systems>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
