@@ -1,7 +1,7 @@
 use strict;
 use warnings;
-package Software::License::CC0_1_0;
-$Software::License::CC0_1_0::VERSION = '0.104003';
+package Software::License::CC0_1_0 0.104005;
+
 use parent 'Software::License';
 # ABSTRACT: the "public domain"-like CC0 license, version 1.0
 
@@ -37,7 +37,7 @@ Software::License::CC0_1_0 - the "public domain"-like CC0 license, version 1.0
 
 =head1 VERSION
 
-version 0.104003
+version 0.104005
 
 =head1 PERL VERSION
 
@@ -66,7 +66,7 @@ it.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@semiotic.systems>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
