@@ -1,7 +1,7 @@
 use strict;
 use warnings;
-package Software::License::None;
-$Software::License::None::VERSION = '0.104004';
+package Software::License::None 0.104005;
+
 use parent 'Software::License';
 # ABSTRACT: describes a "license" that gives no license for re-use
 
@@ -23,7 +23,7 @@ Software::License::None - describes a "license" that gives no license for re-use
 
 =head1 VERSION
 
-version 0.104004
+version 0.104005
 
 =head1 PERL VERSION
 
@@ -41,7 +41,7 @@ lower the minimum required perl.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@semiotic.systems>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
