@@ -1,7 +1,7 @@
 use strict;
 use warnings;
-package Software::License::OpenSSL;
-$Software::License::OpenSSL::VERSION = '0.104003';
+package Software::License::OpenSSL 0.104005;
+
 use parent 'Software::License';
 # ABSTRACT: The OpenSSL License
 
@@ -33,7 +33,7 @@ Software::License::OpenSSL - The OpenSSL License
 
 =head1 VERSION
 
-version 0.104003
+version 0.104005
 
 =head1 PERL VERSION
 
@@ -51,7 +51,7 @@ lower the minimum required perl.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@semiotic.systems>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
