@@ -1,7 +1,7 @@
 use strict;
 use warnings;
-package Software::License::QPL_1_0;
-$Software::License::QPL_1_0::VERSION = '0.104003';
+package Software::License::QPL_1_0 0.104005;
+
 use parent 'Software::License';
 # ABSTRACT: The Q Public License, Version 1.0
 
@@ -24,7 +24,7 @@ Software::License::QPL_1_0 - The Q Public License, Version 1.0
 
 =head1 VERSION
 
-version 0.104003
+version 0.104005
 
 =head1 PERL VERSION
 
@@ -42,7 +42,7 @@ lower the minimum required perl.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@semiotic.systems>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
